@@ -2,11 +2,12 @@ from __future__ import unicode_literals
 
 import logging
 
-from dvc.config import NoRemoteError
-from dvc.exceptions import DownloadError, OutputNotFoundError
-from dvc.scm.base import CloneError
-from dvc.external_repo import external_repo
 from dvc.cache import NamedCache
+from dvc.config import NoRemoteError
+from dvc.exceptions import DownloadError
+from dvc.exceptions import OutputNotFoundError
+from dvc.external_repo import external_repo
+from dvc.scm.base import CloneError
 
 
 logger = logging.getLogger(__name__)
